@@ -4,3 +4,5 @@
 from . import frontend
 from . import backend
 from . import optimizer
+from . import utils
+from . import ir
